import { LifeCircle, BaseConfiguration, ExtraConfiguration } from 'miniprogram-network-life-circle';
import { defaultDowanloadTransformSend, defaultDownloadTransformResponse } from './transform';
/**
 * 默认配置信息
 */
export declare type DownloadInit = BaseConfiguration<DownloadOption, wx.DownloadFileOption>;
/**
 * 全部配置信息
 */
export interface DownloadOption extends DownloadInit, ExtraConfiguration<wx.DownloadTask> {
    url: NonNullable<string>;
    filePath?: string;
    onProgress?: wx.DownloadTask['offProgressUpdate'];
}
export declare class Downloder extends LifeCircle<wx.DownloadFileOption, wx.DownloadTask, DownloadInit, DownloadOption> {
    /**
     * 默认下载请求参数转换函数
     */
    readonly TransformSend: typeof defaultDowanloadTransformSend;
    /**
     * 默认下载返回数据转换函数
     */
    readonly TransformResponse: typeof defaultDownloadTransformResponse;
    /**
     * 新建 Http实列
     * @param config 全局默认配置
     */
    constructor(config?: DownloadInit, downloader?: (o: wx.DownloadFileOption) => wx.DownloadTask);
    /**
     * 快速下载
     * @param url 下载地址
     * @param filePath 本地文件路径
     * @param options 其他参数
     */
    download<T>(url: string, filePath?: string, options?: Exclude<DownloadOption, 'url' | 'filePath'>): Promise<T>;
    /**
     * Object 参数自定义下载
     * @param options
     */
    download<T>(options: DownloadOption): Promise<T>;
}
